@@ -13,7 +13,10 @@ import cdk8s_plus_17._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk8s-mongo-sts", "0.0.8", __name__[0:-6], "cdk8s-mongo-sts@0.0.8.jsii.tgz"
+    "@opencdk8s/cdk8s-mongo-sts",
+    "0.0.10",
+    __name__[0:-6],
+    "cdk8s-mongo-sts@0.0.10.jsii.tgz",
 )
 
 __all__ = [
